@@ -29,59 +29,22 @@
 #include <Lum/Object.h>
 #include <Lum/String.h>
 
-struct Shortcut
-{
-  std::wstring display;
-  std::wstring value;
-
-  Shortcut(const std::wstring& display,
-           const std::wstring& value)
-   : display(display),
-     value(value)
-  {
-    // no code
-  }
-
-  Shortcut(const std::wstring& value)
-   : display(value),
-     value(value)
-  {
-    // no code
-  }
-};
-
-typedef Lum::Model::StdTable<Shortcut>       ShortcutsModel;
-typedef Lum::Base::Reference<ShortcutsModel> ShortcutsModelRef;
-
-class ShortcutsDataProvider : public ShortcutsModel::DataProvider
-{
-public:
-  std::wstring GetString(const ShortcutsModel::Iterator& iter, size_t column) const
-  {
-    return iter->display;
-  }
-};
-
 class FunctionInput : public Lum::Component
 {
 private:
   Lum::String                                *string;
   std::map<Lum::Model::Action*,std::wstring> actionTextMap;
-  ShortcutsModelRef                          constants;
-  Lum::Model::SingleLineSelectionRef         constantSelection;
   Lum::Model::ActionRef                      constantAction;
-  ShortcutsModelRef                          functions;
-  Lum::Model::SingleLineSelectionRef         functionSelection;
   Lum::Model::ActionRef                      functionAction;
-  ShortcutsModelRef                          trigometrics;
-  Lum::Model::SingleLineSelectionRef         trigometricSelection;
   Lum::Model::ActionRef                      trigometricAction;
   Lum::Model::ActionRef                      backspaceAction;
   Lum::Model::ActionRef                      clearAction;
   Lum::Model::ActionRef                      calculateAction;
+  Lum::Button                                *constantButton;
+  Lum::Button                                *functionButton;
+  Lum::Button                                *trigometricButton;
 
 private:
-  Lum::Object* CreateButton(const std::wstring& label, Lum::Model::Action *action=NULL) const;
   Lum::Object* CreateTextButton(const std::wstring& label, const std::wstring& text=L"");
 
 public:
