@@ -432,7 +432,7 @@ public:
 
   void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
   {
-    Lum::Dlg::ActionDialog::CreateActionInfosClose(actions,GetClosedAction());
+    Lum::Dlg::ActionDialog::CreateActionInfosOkCancel(actions,okAction,GetClosedAction());
   }
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
